@@ -27,16 +27,15 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: script.py 4028 2008-07-11 18:27:51Z joanied $"
-__version__   = "$Revision: 4028 $"
-__date__      = "$Date: 2008-07-11 14:27:51 -0400 (Fri, 11 Jul 2008) $"
+__id__        = "$Id$"
+__version__   = "$Revision$"
+__date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import gtk
 import pyatspi
 
-import orca.braille as braille
 import orca.debug as debug
 import orca.default as default
 import orca.input_event as input_event
@@ -48,7 +47,6 @@ import orca.speech as speech
 from orca.orca_i18n import _
 
 from speech_generator import SpeechGenerator
-from where_am_i import WhereAmI
 import script_settings
 
 ########################################################################
@@ -261,12 +259,6 @@ class Script(default.Script):
 
         return SpeechGenerator(self)
 
-    def getWhereAmI(self):
-        """Returns the 'where am I' class for this script.
-        """
-        
-        return WhereAmI(self)
-
     def getAppPreferencesGUI(self):
         """Return a GtkVBox contain the application unique configuration
         GUI items for the current application.
@@ -528,7 +520,7 @@ class Script(default.Script):
 
         if len(text.strip()):
             speech.speak(text)
-        braille.displayMessage(text)
+        self.displayBrailleMessage(text)
 
     def readPreviousMessage(self, inputEvent):
         """ Speak/braille a previous chat room message. Up to nine
@@ -687,6 +679,15 @@ class Script(default.Script):
         if self.isBuddyListEvent(event):
             return
 
+        # Handle non-chat text areas (e.g., adding a new account)
+        # the default way.
+        #
+        state = event.source.getState()
+        if state.contains(pyatspi.STATE_EDITABLE) \
+           and state.contains(pyatspi.STATE_SINGLE_LINE):
+            default.Script.onTextInserted(self, event)
+            return
+
         chatRoomTab = self.getChatRoomTab(event.source)
         if not chatRoomTab:
             default.Script.onTextInserted(self, event)
@@ -803,7 +804,7 @@ class Script(default.Script):
             # it's not selected.
             #
             text = event.any_data
-            if text.isupper():
+            if text.decode("UTF-8").isupper():
                 speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
             else:
                 speech.speak(text)
