@@ -43,7 +43,6 @@ import pyatspi
 import orca.debug as debug
 import orca.default as default
 import orca.input_event as input_event
-import orca.braille as braille
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.speech as speech
@@ -1034,7 +1033,7 @@ class Script(default.Script):
             #
             line = _("Dynamic column header set for row %d") % (row+1)
             speech.speak(line)
-            braille.displayMessage(line)
+            self.displayBrailleMessage(line)
 
         return True
 
@@ -1058,7 +1057,7 @@ class Script(default.Script):
                 line = _("Dynamic column header cleared.")
                 speech.stop()
                 speech.speak(line)
-                braille.displayMessage(line)
+                self.displayBrailleMessage(line)
             except:
                 pass
 
@@ -1111,7 +1110,7 @@ class Script(default.Script):
             line = _("Dynamic row header set for column %s") \
                    % self.columnConvert(column+1)
             speech.speak(line)
-            braille.displayMessage(line)
+            self.displayBrailleMessage(line)
 
         return True
 
@@ -1135,7 +1134,7 @@ class Script(default.Script):
                 line = _("Dynamic row header cleared.")
                 speech.stop()
                 speech.speak(line)
-                braille.displayMessage(line)
+                self.displayBrailleMessage(line)
             except:
                 pass
 
@@ -1506,8 +1505,7 @@ class Script(default.Script):
                 result = self.getTextLineAtCaret(event.source)
                 textToSpeak = result[0].decode("UTF-8")
                 self._speakWriterText(event, textToSpeak)
-                braille.displayRegions(\
-                    brailleGen.generateBraille(event.source))
+                self.displayBrailleForObject(event.source)
                 return
 
         # Check to see if the object that just got focus is in the Setup
@@ -1894,6 +1892,14 @@ class Script(default.Script):
                and event.any_data:
                 handleEvent = True
 
+            # The style list in the Formatting toolbar also lacks state
+            # focused.
+            #
+            elif event.any_data and self.getAncestor(event.source,
+                                                     [pyatspi.ROLE_TOOL_BAR],
+                                                     [pyatspi.ROLE_FRAME]):
+                handleEvent = True
+
         elif self.isSameObject(orca_state.locusOfFocus, event.source.parent) \
              and event.source.getRole() == pyatspi.ROLE_LIST \
              and orca_state.locusOfFocus.getRole() == pyatspi.ROLE_COMBO_BOX:
@@ -1912,6 +1918,16 @@ class Script(default.Script):
             handleEvent = True
             presentEvent = False
 
+        if orca_state.locusOfFocus \
+           and self.isSameObject(orca_state.locusOfFocus, event.any_data):
+            # We're already on the new item. If we (or the default script)
+            # presents it, the speech.stop() will cause us to interrupt the
+            # presentation we're probably about to make due to an earlier
+            # event.
+            #
+            handleEvent = True
+            presentEvent = False
+
         if handleEvent:
             if presentEvent:
                 speech.stop()
@@ -2097,12 +2113,10 @@ class Script(default.Script):
                                             # has a formula
                                             # (e.g., "=sum(a1:d1)")
                                             #
-                                            hf = " " + _("has formula")
-                                            speech.speak(hf, None, False)
-
-                                            line = braille.getShowingLine()
-                                            line.addRegion(braille.Region(hf))
-                                            braille.refresh()
+                                            hf = _("has formula")
+                                            speech.speak(" %s" % hf,
+                                                         None, False)
+                                            self.presentItemsInBraille([hf])
                                             #
                                             # Fall-thru to process the event
                                             # with the default handler.
@@ -2261,9 +2275,19 @@ class Script(default.Script):
             result = self.getText(event.source, 0, -1)
             textToSpeak = result.decode("UTF-8")
             self._speakWriterText(event, textToSpeak)
-            braille.displayRegions( \
-                self.brailleGenerator.generateBraille(event.source))
+            self.displayBrailleForObject(event.source)
         else:
+            # The lists and combo boxes in the Formatting toolbar emit
+            # object:active-descendant-changed events which cause us
+            # to set the locusOfFocus to the list item. If the user then
+            # arrows within the text portion, we will not present it due
+            # to the event not being from the locusOfFocus.
+            #
+            if event.source.getRole() == pyatspi.ROLE_TEXT \
+               and self.getAncestor(event.source,
+                                    [pyatspi.ROLE_TOOL_BAR],
+                                    [pyatspi.ROLE_FRAME]):
+                orca.setLocusOfFocus(event, event.source, False)
             default.Script.onCaretMoved(self, event)
 
         # If we're still here, we must be convinced that this paragraph
@@ -2316,6 +2340,23 @@ class Script(default.Script):
         else:
             default.Script.onTextInserted(self, event)
 
+    def isWordMisspelled(self, obj, offset):
+        """Identifies if the current word is flagged as misspelled by the
+        application.
+
+        Arguments:
+        - obj: An accessible which implements the accessible text interface.
+        - offset: Offset in the accessible's text for which to retrieve the
+          attributes.
+
+        Returns True if the word is flagged as misspelled.
+        """
+
+        attributes, start, end  = self.getTextAttributes(obj, offset, True)
+        error = attributes.get("text-spelling")
+
+        return error == "misspelled"
+
     def getTextAttributes(self, acc, offset, get_defaults=False):
         """Get the text attributes run for a given offset in a given accessible
 
