@@ -352,8 +352,8 @@ class SpeechGenerator(generator.Generator):
         except:
             pass
         else:
-            role = pyatspi.ROLE_IMAGE
-            result.extend(self.generate(obj, role=role))
+            args['role'] = pyatspi.ROLE_IMAGE
+            result.extend(self.generate(obj, **args))
         return result
 
     #####################################################################
@@ -1217,14 +1217,18 @@ class SpeechGenerator(generator.Generator):
         relations = obj.getRelationSet()
         for relation in relations:
             if relation.getRelationType() == pyatspi.RELATION_MEMBER_OF:
-                total = relation.getNTargets()
-                for i in range(0, total):
+                total = 0
+                for i in range(0, relation.getNTargets()):
                     target = relation.getTarget(i)
-                    if target == obj:
-                        position = total - i
-                        break
+                    if target.getState().contains(pyatspi.STATE_SHOWING):
+                        total += 1
+                        if target == obj:
+                            position = total
 
         if position >= 0:
+            # Adjust the position because the relations tend to be given
+            # in the reverse order.
+            position = total - position + 1
             result.append(self._script.formatting.getString(
                               mode='speech',
                               stringType='groupindex') \
@@ -1292,16 +1296,16 @@ class SpeechGenerator(generator.Generator):
 
         if not total:
             for child in obj:
-                next = self._generateName(child)
+                nextName = self._generateName(child)
                 state = child.getState()
-                if not next or next[0] in ["", "Empty", "separator"] \
+                if not nextName or nextName[0] in ["", "Empty", "separator"] \
                    or not state.contains(pyatspi.STATE_VISIBLE):
                     continue
 
                 index += 1
                 total += 1
 
-                if next == name:
+                if nextName == name:
                     position = index
 
         if (settings.enablePositionSpeaking \
